@@ -41,7 +41,7 @@ class SsoStrategy:
         'provision_company': None,     # string - Default company for auto provisioned users.
         'ldap_base_dn': None,     # string - Base DN for looking up users in LDAP server
         'ldap_domain': None,     # string - Domain name that will be appended to LDAP usernames
-        'enabled': None,     # boolean - Is strategy enabled?
+        'enabled': None,     # boolean - Is strategy enabled?  This may become automatically set to `false` after a high number and duration of failures.
         'ldap_host': None,     # string - LDAP host
         'ldap_host_2': None,     # string - LDAP backup host
         'ldap_host_3': None,     # string - LDAP backup host
